#!/usr/bin/python3

import time
from .colors import colors

time_start = None

	
def progress(index, total):
	bar = '|' + colors.bg.green
	for i in range (100):
		if (index / (total - 1)) > (i / 100) :
			bar += ' '
		elif bar.find(colors.reset) == -1:
			bar += colors.reset
		else:
			bar += ' '
	bar += colors.reset + colors.fg.green + '|' + colors.reset + colors.bold
	return bar, round((index / (total - 1))*100, 2)


def get_time_str(time):
	if (time < 60):
		return str(round(time, 2)) + 's' 
	time /= 60
	if (time < 60):
		return str(round(time, 2)) + 'm' 
	time /= 60
	if (time < 60):
		return str(round(time, 2)) + 'h'


def get_times(percentage):
	global time_start
	curr_time = time.time() - time_start

	try:
		eta = get_time_str(((curr_time * 100) / percentage) - curr_time)
	except Exception as e:
		eta = "inf"
	finally:
		return get_time_str(curr_time), eta


def status_bar(index, total, message = ''):
	global time_start

	if time_start == None:
		time_start = time.time()

	if index == total - 1:
		end = '\n'
	else:
		end = '\r'

	progress_bar, percentage = progress(index, total)
	curr_time, eta = get_times(percentage)

	print(f"{colors.bold}{colors.fg.lightcyan}Status: {colors.fg.purple}Time: {colors.fg.lightblue}{curr_time} {colors.fg.purple}ETA: {colors.fg.lightblue}{eta} {colors.fg.green}{progress_bar} {colors.fg.red}{percentage} % Done. {colors.fg.yellow}{message}{colors.reset}", end=end, flush=True)



#!/usr/bin/python3

class colors: 
    ''' Colors class:reset all colors with colors.reset; two sub classes fg for foreground and bg for background; 
        use as colors.subclass.colorname.i.e. colors.fg.red or colors.bg.green
        the generic bold, disable, underline, reverse, strike through, and invisible work with the main class i.e. colors.bold
    '''

    reset='\033[0m'
    bold='\033[01m'
    disable='\033[02m'
    underline='\033[04m'
    reverse='\033[07m'
    strikethrough='\033[09m'
    invisible='\033[08m'
    
    class fg: 
        black='\033[30m'
        red='\033[31m'
        green='\033[32m'
        orange='\033[33m'
        blue='\033[34m'
        purple='\033[35m'
        cyan='\033[36m'
        lightgrey='\033[37m'
        darkgrey='\033[90m'
        lightred='\033[91m'
        lightgreen='\033[92m'
        yellow='\033[93m'
        lightblue='\033[94m'
        pink='\033[95m'
        lightcyan='\033[96m'

    class bg: 
        black='\033[40m'
        red='\033[41m'
        green='\033[42m'
        orange='\033[43m'
        blue='\033[44m'
        purple='\033[45m'
        cyan='\033[46m'
        lightgrey='\033[47m'


import setuptools

with open("README.md", "r") as f:
    long_description = f.read()

setuptools.setup(
    name="smart-status-bar",
    version="1.0",
    author="Shreyansh Nagpal",
    author_email="shreyanshnagpal7499@gmail.com",
    description="A smart status bar for loops.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Shreyansh7499/smart-status-bar",
    packages=['smart_status_bar'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)

